@@ -24,12 +24,6 @@ class Enums:
     CONTENT_FILE = 'application/pdf'
     TYPE_FILE = ['png', 'gif', 'jpg', 'jpeg', 'mp4', 'pdf']
 
-    COMMUNITY = "community"
-    REQUEST_COMMUNITY = "request-community"
-    PUBLICATION = "publication"
-    FULL_TEXT = "full_text"
-    USER = "user"
-
 
 class Constants:
     FORMAT_DATE_TIME = '%d-%m-%Y %H:%M:%S'
@@ -44,6 +38,10 @@ class Constants:
     INVALID = 'INVALIDO'
 
 
+class FrontendUrl:
+    URL_BASE_COMMUNITY = '/tesis-asn/users/community/'
+
+
 class DynamicFieldsSerializer(serializers.ModelSerializer):
     def __init__(self, *args, **kwargs):
         fields = kwargs.pop('fields', None)
